# Atarg
Utility tools for AtCoder

## Install
```
pip install atarg
```

## Usage
```
usage: atarg [-h] [-s]
             {ABC,ARC,AGC,abc,arc,agc} contest_no {A,B,C,D,a,b,c,d}
             command [command ...]]
```
### Run on test cases
```
atarg ABC 077 C ./C
```

### Submit
```
atarg -s ABC 077 C C.rs
```
